#!/usr/bin/python3.8
import argparse
from datetime import datetime, timedelta
from pathlib import Path

from collect.collector.collector import Collector
from collect.configuration.collect_configuration import CollectConfiguration


def parse_args() -> argparse.Namespace:
    now = datetime.utcnow()
    range_start = now - timedelta(days=3, hours=now.hour)
    range_end = now

    parser = argparse.ArgumentParser('collect args')
    parser.add_argument('--output-dir', type=Path)
    parser.add_argument('--no-prometheus', action='store_true', help='skip prometheus metrics dump')
    parser.add_argument('--siem-logs-range-start', type=datetime.fromisoformat, default=range_start,
                        help='start datetime to fetch logs for (format YYYY-MM-DD-HH)')
    parser.add_argument('--siem-logs-range-end', type=datetime.fromisoformat, default=range_end,
                        help='end date to fetch logs for (format YYYY-MM-DD-HH)')
    parser.add_argument('--no-siem-logs', action='store_true', help='skip siem logs collecting')
    return parser.parse_args()


def main():
    args = parse_args()
    configuration = CollectConfiguration.from_file()
    if args.output_dir:
        configuration.output_collect_dir = args.output_dir
    configuration.siem_logs_range_start = args.siem_logs_range_start
    configuration.siem_logs_range_end = args.siem_logs_range_end
    configuration.no_prometheus = args.no_prometheus
    configuration.no_siem_logs = args.no_siem_logs
    Collector(configuration=configuration).run()
