from collect.configuration.collect_configuration import CollectConfiguration
from collect.helpers.utils import collect_env_file, read_write_env_file
from collect.tasks.collect_task import CollectTask


class CollectHostFilesTask(CollectTask):
    TITLE = 'Collect host files'
    COLLECT_ENV_DIR = 'environment'
    FUNCTIONS = [
        lambda target: collect_env_file('/etc/cron.d/', f'{target}/cron.d'),
        lambda target: collect_env_file('/etc/cron.daily/', f'{target}/cron.daily'),
        lambda target: collect_env_file('/etc/cron.hourly/', f'{target}/cron.hourly'),
        lambda target: collect_env_file('/etc/cron.monthly/', f'{target}/cron.monthly'),
        lambda target: collect_env_file('/etc/cron.weekly/', f'{target}/cron.weekly'),
        lambda target: collect_env_file('/etc/crontab', f'{target}/crontab'),
        lambda target: collect_env_file('/etc/group', f'{target}/group'),
        lambda target: collect_env_file('/etc/hosts', f'{target}/hosts'),
        lambda target: collect_env_file('/etc/kaspersky/node.json', f'{target}/node.json'),
        lambda target: collect_env_file('/etc/network', f'{target}/network'),
        lambda target: collect_env_file('/etc/passwd', f'{target}/passwd'),
        lambda target: collect_env_file('/etc/resolv.conf', f'{target}/resolv.conf'),
        lambda target: collect_env_file('/proc/net/dev', f'{target}/dev.txt'),
        lambda target: read_write_env_file('/etc/issue', f'{target}/issue.txt'),
        lambda target: read_write_env_file('/proc/cpuinfo', f'{target}/cpuinfo.txt'),
    ]

    def _run(self):
        for f in self.FUNCTIONS:
            try:
                f(target=self._configuration.work_dir / self.COLLECT_ENV_DIR)
            except Exception as ex:
                self._logger.error(f'Error during collect: {ex}, skip step')


if __name__ == '__main__':
    CollectHostFilesTask(CollectConfiguration()).run_task()
