from collect.configuration.collect_configuration import CollectConfiguration
from collect.helpers.utils import dump_shell_command
from collect.tasks.collect_task import CollectTask


class CollectShellOutputTask(CollectTask):
    TITLE = 'Collect shell command output'
    COLLECT_ENV_DIR = 'environment'

    def __init__(self, configuration: CollectConfiguration):
        super().__init__(configuration)
        self.SOURCES = [
            ('apt list --installed', 'debdbl.txt', True),
            ('date', 'date.txt', True),
            ('df -h', 'hdd-h.txt', True),
            ('df -hi', 'hdd-hi.txt', True),
            ('find /sys/devices/virtual/dmi/id/ -maxdepth 1 -type f | xargs cat', 'devices_virtual', True),
            ('free -m', 'memory.txt', True),
            ('hostname', 'hostname.txt', True),
            ('ifconfig', 'ifconfig.txt', True),
            ('iostat -xk 1 3', 'iostat.txt', True),
            ('ip a', 'ipa.txt', True),
            ('ip r', 'ipr.txt', True),
            ('ip xfrm policy', 'ipsec-policy.txt', True),
            ('ip xfrm state', 'ipsec-state.txt', True),
            ('iptables -L', 'iptables.txt', True),
            ('ls -la / /tmp /opt /var /etc', 'lsroot.txt', True),
            ('ls -laR /etc/kaspersky', 'lskasp.txt', True),
            ('lsmod', 'lsmod.txt', True),
            ('mount', 'mount.txt', True),
            ('netstat -na', 'netstat.txt', True),
            ('ping -c2 support.kaspersky.com', 'ping.txt', True),
            ('ps axo pid,pcpu,pmem,rsz,vsz,cmd', 'ps.txt', True),
            ('route -n', 'route.txt', True),
            ('sysctl -a', 'sysctl.txt', True),
            ('systemctl list-units', 'systemctl_units.txt', True),
            ('ulimit -a', 'ulimit.txt', True),
            ('uname -a', 'uname.txt', True),
            ('uptime', 'uptime.txt', True),
            ('vmstat -D', 'vmstatd2.txt', True),
            ('vmstat -d', 'vmstatd.txt', True),
            ('vmstat -m', 'vmstatm.txt', True),
            ('vmstat -s', 'vmstats.txt', True),
            ('vmstat', 'vmstat.txt', True),
            ('apt list --installed | grep -i apt', 'aapt_info_debs.txt', True),
            ('systemctl status', 'aapt_info_systemctl.txt', True),
            ('docker ps', 'docker_ps.txt', True),
            ('docker service ls', 'docker_service_ls.txt', True),
            (
                'curl -s http://127.0.0.1:9090/api/v1/label/__name__/values | tr \'","\' "\n" | grep preprocessor_ '
                '| xargs -I {} curl -s http://127.0.0.1:9090/api/v1/query?query={} '
                '| grep -oP "((?<=__\\":).+?\\"value\\":.+?)(?=})"',
                'prometheus_preprocessor_metrics.txt',
                not configuration.no_prometheus
            ),
            (
                'curl -s http://127.0.0.1:9090/api/v1/label/__name__/values | tr \'","\' "\n" | grep suricata_ '
                '| xargs -I {} curl -s http://127.0.0.1:9090/api/v1/query?query={} '
                '| grep -oP "((?<=__\\":).+?\\"value\\":.+?)(?=})"',
                'prometheus_suricata_metrics.txt',
                not configuration.no_prometheus
            ),
        ]

    def _run(self):
        target_dir = self._configuration.work_dir / self.COLLECT_ENV_DIR
        target_dir.mkdir(parents=True, exist_ok=True)

        for src, dst, should_run in self.SOURCES:
            if not should_run:
                continue
            try:
                dump_shell_command(cmd=src, output=str(target_dir / dst))
            except Exception as ex:
                self._logger.warning(f'Error during collect: {ex}, skip step')


if __name__ == '__main__':
    CollectShellOutputTask(CollectConfiguration()).run_task()
