from base_installer.enums.node import NodeType
from collect.configuration.collect_configuration import CollectConfiguration
from collect.helpers.utils import stream_dir_from_container
from collect.tasks.collect_task import CollectTask
from docker_utils import DockerException


class CopyContainerDirsTask(CollectTask):
    TITLE = 'Collect container dirs task'
    COLLECT_DIR = 'configs'
    SOURCES = [
        ('preprocessor_external', '/var/opt/kaspersky/apt/snort/rules', 'rules_preprocessor_external.tar.gz',),
        ('preprocessor_pop', '/var/opt/kaspersky/apt/snort/rules', 'rules_preprocessor_pop.tar.gz',),
        ('preprocessor_span', '/var/opt/kaspersky/apt/snort/rules', 'rules_preprocessor_span.tar.gz',),
        ('preprocessor', '/var/opt/kaspersky/apt/snort/rules', 'rules_preprocessor.tar.gz',),
        ('updater', '/storage/apt/snort/rules', 'rules_updater.tar.gz',),
        ('web_backend', '/var/opt/kaspersky/apps/apt-collector', 'apt-collector_web_backend.tar.gz',),
        ('suricata', '/var/lib/suricata/rules', 'rules_suricata_var_lib.tar.gz',),
        ('suricata', '/etc/suricata/rules', 'rules_suricata_etc.tar.gz',),
    ]

    def _check_if_task_should_run(self) -> bool:
        return self._configuration.node_type in (NodeType.STORAGE, NodeType.COMPUTATION)

    def _run(self):
        for container, source, dest in self.SOURCES:
            dest = self._configuration.work_dir / self.COLLECT_DIR / dest
            try:
                self._logger.info(F'Copy dir {container}:{source} -> {dest}')
                stream_dir_from_container(container, source, str(dest))
            except DockerException as ex:
                if 'No such file or directory' in str(ex):
                    self._logger.warning(f'Nothing to collect from {source} yet, skip step ')
            except RuntimeError as ex:
                self._logger.warning(str(ex))
            except Exception as ex:
                self._logger.error(f'Collect error: {ex}, skip step')


if __name__ == '__main__':
    CopyContainerDirsTask(CollectConfiguration(node_type='single')).run_task()  # type: ignore
