from base_installer.enums.node import NodeType
from collect.configuration.collect_configuration import CollectConfiguration
from collect.helpers.utils import stream_file_from_container
from collect.tasks.collect_task import CollectTask


class CopyContainerFilesTask(CollectTask):
    TITLE = 'Collect container files task'
    COLLECT_DIR = 'configs'
    SOURCES = [
        ('edr_synchronizer', '/var/opt/kaspersky/apps/apt-collector', 'apt-collector_edr_synchronizer',),
        ('kata_scanner', '/var/opt/kaspersky/apps/apt-agents-id', 'apt-agents-id_kata_scanner',),
        ('kata_scanner', '/var/opt/kaspersky/apps/apt-collector', 'apt-collector_kata_scanner',),
        ('kata_scanner', '/var/opt/kaspersky/apps/apt-scan-server', 'apt-scan-server_kata_scanner',),
        ('kata_scanner', '/var/opt/kaspersky/apps/apt-updater', 'apt-updater_kata_scanner',),
        ('kata_scanner', '/var/opt/kaspersky/apt-scan-server/data/vm_config.json', 'vm_config.json',),
        ('kata_scanner', '/var/opt/kaspersky/apps/apt-va', 'apt-va_kata_scanner',),
        ('preprocessor_external', '/var/opt/kaspersky/apps/apt-preprocessor', 'apt-preprocessor_preprocessor_external',),
        ('preprocessor_external', '/var/opt/kaspersky/apt-preprocessor/preprocessor.conf', 'preprocessor_external.conf',),
        ('preprocessor_pop', '/var/opt/kaspersky/apps/apt-preprocessor', 'apt-preprocessor_preprocessor_pop',),
        ('preprocessor_pop', '/var/opt/kaspersky/apt-preprocessor/preprocessor.conf', 'preprocessor_pop.conf',),
        ('preprocessor_span', '/var/opt/kaspersky/apps/apt-preprocessor', 'apt-preprocessor_preprocessor_span',),
        ('preprocessor_span', '/var/opt/kaspersky/apt-preprocessor/preprocessor.conf', 'preprocessor_span.conf',),
        ('preprocessor', '/var/opt/kaspersky/apps/apt-preprocessor', 'apt-preprocessor_preprocessor',),
        ('preprocessor', '/var/opt/kaspersky/apt-preprocessor/preprocessor.conf', 'preprocessor.conf',),
        ('suricata', '/etc/suricata/suricata.yaml', 'suricata.yaml',),
        ('updater', '/var/opt/kaspersky/apps/apt-updater', 'apt-updater_updater',),
        ('web_backend', '/var/opt/kaspersky/apps/apt-monitor', 'apt-monitor_web_backend',),
        ('web_backend', '/var/opt/kaspersky/apps/apt-va', 'apt-va_web_backend',),
        ('web_backend', '/var/opt/kaspersky/apps/apt-monitor-primary', 'apt-monitor-primary_web_backend',),
        ('web_backend', '/var/opt/kaspersky/apps/apt-agents-id', 'apt-agents-id_web_backend',),
    ]

    def _check_if_task_should_run(self) -> bool:
        return self._configuration.node_type in (NodeType.STORAGE, NodeType.COMPUTATION)

    def _run(self):
        for container, source, dest in self.SOURCES:
            dest = self._configuration.work_dir / self.COLLECT_DIR / dest
            try:
                # NOTE docker cp tries to mount a volume to copy files from which our RBD configuration prohibits
                #  use "cat filename > output" command instead
                self._logger.info(F'Copy file {container}:{source} -> {dest}')
                stream_file_from_container(container, source, str(dest))
            except Exception as ex:
                self._logger.warning(f'Collect warning: {ex}, skip step')


if __name__ == '__main__':
    CopyContainerFilesTask(CollectConfiguration(node_type='single')).run_task()  # type: ignore
