from pathlib import Path

from collect.constants import LogNames, SiemProxyApiInfo
from collect.helpers.logs_downloader import LogsDownloader
from collect.tasks.collect_task import CollectTask


class DownloadSiemLogsTask(CollectTask):
    TITLE = 'Download SIEM logs task'

    TARGET_DIR_RELATIVE_PATH = Path('logs/kaspersky/siem')

    def _run(self):
        if self._configuration.no_siem_logs:
            return
        target_dir = self._configuration.work_dir / self.TARGET_DIR_RELATIVE_PATH
        target_dir.mkdir(parents=True, exist_ok=True)
        self.download_logs(target_dir)

    def download_logs(self, target_dir: Path):
        dl = LogsDownloader(
            host=SiemProxyApiInfo.external_connection_host,
            port=SiemProxyApiInfo.external_connection_port,
        )

        for log_name in LogNames:
            self._logger.info(f'Downloading {log_name}...')
            try:
                dl.download(log_name.value,
                            target_file=target_dir / f'{log_name}.zip',
                            range_start=self._configuration.siem_logs_range_start,
                            range_end=self._configuration.siem_logs_range_end)
            except Exception:
                self._logger.info(f'Log {log_name} doesn\'t exist, skip. Use DEBUG log level to see the details')
                self._logger.debug(f'Error getting {log_name}, skip', exc_info=True)
