from confluent_kafka import KafkaError

from base_installer.enums.node import NodeType
from collect.configuration.collect_configuration import CollectConfiguration
from collect.helpers.utils import dump_shell_command
from collect.tasks.collect_task import CollectTask


class DumpKafkaTopicsTask(CollectTask):
    TITLE = 'Dump selected Kafka topics'
    COLLECT_DIR = 'dumps/kafka'
    KAFKA_HOST = '127.0.0.1'
    KAFKA_PORT = 10000
    COUNT = 1000
    TIMEOUT = 10
    TOPICS = [
        'ResponseActionsFailedTopic',
        'AllDetectsFailedTopic',
        'FastSearchImportFailedTopic',
        'EndpointEnrichFailedTopic',
        'EndpointFailedEventsTopic',
    ]

    def _check_if_task_should_run(self) -> bool:
        return not self._configuration.node_type == NodeType.SENSOR

    def _run(self):
        target_dir = self._configuration.work_dir / self.COLLECT_DIR
        target_dir.mkdir(parents=True, exist_ok=True)

        for topic in self.TOPICS:
            try:
                dump_shell_command(
                    f'kata-kafka-client topic-consume {topic} '
                    f'--from-beginning --count {self.COUNT} --timeout {self.TIMEOUT}',
                    f'{target_dir}/{topic}.txt'
                ),
            except KafkaError:
                self._logger.warning('Kafka instances not present on the current node, skip step')
            except Exception as ex:
                self._logger.error(f'Error collecting topic {topic}: {ex}')


if __name__ == '__main__':
    DumpKafkaTopicsTask(CollectConfiguration(node_type='single')).run_task()  # type: ignore
