from collect.configuration.collect_configuration import CollectConfiguration
from collect.helpers.utils import db_exists, docker_exec_sql_command, ensure_container_exists
from collect.tasks.collect_task import CollectTask


class DumpPostgresTask(CollectTask):
    TITLE = 'Dump postgres databases task'
    COLLECT_DIR = 'dumps/postgres'
    CONTAINER_NAME = 'kedr_database'
    ANTIAPT_DB_NAME = 'antiapt'
    AGENT_DB_NAME = 'agent_database'

    def _check_if_task_should_run(self) -> bool:
        container_id = None
        try:
            container_id = ensure_container_exists(self.CONTAINER_NAME)
        except RuntimeError:
            self._logger.warning(f'Container {self.CONTAINER_NAME} is not present on the current node, skip step')
        return container_id is not None

    def _run(self):
        target_dir = self._configuration.work_dir / self.COLLECT_DIR
        target_dir.mkdir(parents=True, exist_ok=True)

        docker_exec_sql_command(
            self.CONTAINER_NAME,
            self.ANTIAPT_DB_NAME,
            (self._pkg_configs_path / 'postgres_info.psql').read_text(),
            target_dir / 'antiapdb_dump.txt',
        )
        self._logger.info('antiapt dump success')
        docker_exec_sql_command(
            self.CONTAINER_NAME,
            self.AGENT_DB_NAME,
            'SELECT count(*) FROM sensor;',
            target_dir / 'sensor_count.txt',
        )
        self._logger.info('sensor count dump success')

        if db_exists(self.CONTAINER_NAME, 'primarydb'):
            docker_exec_sql_command(
                self.CONTAINER_NAME,
                self.ANTIAPT_DB_NAME,
                (self._pkg_configs_path / 'primarydb_info.psql').read_text(),
                target_dir / 'primarydb_dump.txt',
            )
            self._logger.info('primarydb dump success')


if __name__ == '__main__':
    DumpPostgresTask(CollectConfiguration(node_type='single')).run_task()  # type: ignore
