from base_installer.enums.node import NodeType
from collect.configuration.collect_configuration import CollectConfiguration
from collect.helpers.utils import docker_exec_redis_command, ensure_container_exists
from collect.tasks.collect_task import CollectTask


class DumpRedisTask(CollectTask):
    TITLE = 'Dump redis task'
    COLLECT_DIR = 'configs'
    CONTAINER_NAME = 'kata_scanner'
    SOURCES = [
        ('kata_scanner', 'get am_queue:size', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.amEngine.lastSuccess', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.amEngine.status', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.amEngine.timestamp', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.bases.127.0.0.1.lastSuccess', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.bases.127.0.0.1.status', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.bases.127.0.0.1.timestamp', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.ids.127.0.0.1.status', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.ids.127.0.0.1.timestamp', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.ksn.127.0.0.1.fails', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.ksn.127.0.0.1.lastFailure', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.ksn.127.0.0.1.lastSuccess', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.ksn.127.0.0.1.status', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.ksn.127.0.0.1.timestamp', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.yara.lastSuccess', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.yara.status', 'collect_redis.txt', True),
        ('kata_scanner', 'get health.yara.timestamp', 'collect_redis.txt', True),
        ('kata_scanner', 'get yr_queue:size', 'collect_redis.txt', True),
        ('kata_scanner', 'hgetall health.sandbox.bases', 'collect_redis.txt', True),
        ('kata_scanner', 'hgetall health.sandbox.status', 'collect_redis.txt', True),
        ('kata_scanner', r'keys \*', 'redis-keys.txt', False),
        ('kata_scanner', 'mget sb_queue_0:size sb_queue:size sb_queue_2:size', 'collect_redis.txt', True),
        ('kata_scanner', 'info', 'collect_redis.txt', True),
    ]

    def _check_if_task_should_run(self) -> bool:
        container_id = None
        try:
            container_id = ensure_container_exists(self.CONTAINER_NAME)
        except RuntimeError:
            self._logger.warning('Container kata_scanner is not present on the current node, skip step')
        return self._configuration.node_type in (NodeType.STORAGE, NodeType.COMPUTATION) and container_id is not None

    def _run(self):
        dest = self._configuration.work_dir / self.COLLECT_DIR
        for container, command, out_file, append in self.SOURCES:
            self._logger.info(f'Redis command: {command}')
            docker_exec_redis_command(container, command, str(dest / out_file), append)


if __name__ == '__main__':
    DumpRedisTask(CollectConfiguration(node_type='single')).run_task()  # type: ignore
