from pathlib import Path

from collect.tasks.collect_task import CollectTask
from docker_utils import Swarm


class GetSwarmDiagnosticTask(CollectTask):
    TITLE = 'Get swarm diagnostic'

    SWARM_DIAGNOSTIC_DIR = Path('diagnostic/swarm/')
    NODE_LIST_FILE = 'node_ls'
    SELF_NODE_INFO_FILE = 'node_inspect_self'

    def _run(self):
        dst_dir = self._configuration.work_dir / self.SWARM_DIAGNOSTIC_DIR
        dst_dir.mkdir(parents=True, exist_ok=True)
        self.save_nodes_info(dst_dir)

    def save_nodes_info(self, dst_dir: Path):
        swarm = Swarm()
        nodes = swarm.get_swarm_nodes()

        with open(dst_dir / self.NODE_LIST_FILE, 'w') as nodes_file:
            nodes_file.writelines(nodes)

        if swarm.is_swarm_manager():
            self_node = swarm.inspect_node('self', '.')

            with open(dst_dir / self.SELF_NODE_INFO_FILE, 'w') as self_node_file:
                self_node_file.writelines(self_node)
